==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Encyclopedia/language/lang-german.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/




define("_PREVIOUS","Vorherige Seite");
define("_NEXT","N&auml;chste Seite");

define("_SEARCHRESULTS","Suchergebnisse");
define("_PAGE","Seite");
define("_RETURNTO","Zur&uuml;ck nach");
define("_DEACTIVATE","Deaktivieren");
define("_ACTIVATE","Aktivieren");
define("_ENCYCLOPEDIA","Encyclopedia");
define("_NOCONTENTFORLETTER","Sorry, diese Seite hat keinen Inhalt");
define("_ENCYSELECTLETTER","W&auml;hle einen Buchstaben um die enthaltenen Begriffe aufzulisten:");
define("_COPYRIGHT","Copyright &copy; by $sitename. All Right Reserved.");
define("_YOURADMINENCY","Du bist Administrator, diese Encyclopedia ist nicht aktive!");
define("_ENCYNOTACTIVE","Sorry, diese Encyclopedia ist zur Zeit nicht aktiv.");
define("_AVAILABLEENCYLIST","Liste der verf&uuml;gbaren Encyclopedias in");
define("_YOURADMININACTIVELIST","Du bist Administrator: nachfolgend die inaktiven Encyclopedias:");
define("_NORESULTSTEXT","Keine Ergebnisse im Begriffstext...");
define("_NORESULTSTITLE","Keine Ergebnisse im Begriffstitel...");
define("_SEARCHRESULTSFOR","Suchergebnisse f&uuml;r:");
define("_SEARCHNOTCOMPLETE","Suchoptionen nicht vollst&auml;ndig, versuchs noch einmal.");
define("_RESULTSINTERMTITLE","Ergebnisse im Begriffstitel:");
define("_RESULTSINTERMTEXT","Ergebnisse im Begriffstext:");


?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Encyclopedia/language/lang-german.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/




define("_PREVIOUS","Vorherige Seite");
define("_NEXT","N&auml;chste Seite");

define("_SEARCHRESULTS","Suchergebnisse");
define("_PAGE","Seite");
define("_RETURNTO","Zur&uuml;ck nach");
define("_DEACTIVATE","Deaktivieren");
define("_ACTIVATE","Aktivieren");
define("_ENCYCLOPEDIA","Encyclopedia");
define("_NOCONTENTFORLETTER","Sorry, diese Seite hat keinen Inhalt");
define("_ENCYSELECTLETTER","W&auml;hle einen Buchstaben um die enthaltenen Begriffe aufzulisten:");
define("_COPYRIGHT","Copyright &copy; by $sitename. All Right Reserved.");
define("_YOURADMINENCY","Du bist Administrator, diese Encyclopedia ist nicht aktive!");
define("_ENCYNOTACTIVE","Sorry, diese Encyclopedia ist zur Zeit nicht aktiv.");
define("_AVAILABLEENCYLIST","Liste der verf&uuml;gbaren Encyclopedias in");
define("_YOURADMININACTIVELIST","Du bist Administrator: nachfolgend die inaktiven Encyclopedias:");
define("_NORESULTSTEXT","Keine Ergebnisse im Begriffstext...");
define("_NORESULTSTITLE","Keine Ergebnisse im Begriffstitel...");
define("_SEARCHRESULTSFOR","Suchergebnisse f&uuml;r:");
define("_SEARCHNOTCOMPLETE","Suchoptionen nicht vollst&auml;ndig, versuchs noch einmal.");
define("_RESULTSINTERMTITLE","Ergebnisse im Begriffstitel:");
define("_RESULTSINTERMTEXT","Ergebnisse im Begriffstext:");


?>
